##  Differential view
You can compare changes within a given time frame by applying the differential view to a report. On the time slider at the top of the report, select a point in time, press and hold Shift, then select another point in time. To get meaningful insights using the differential view, select a report view that involves dates, such as Lifecycle.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2746e2547a44101496ab9d74d39de7a0_LowRes.png)
In the differential view combined with the rolled-up layout, users can see the number of changes for each view bucket; in the example below in Employee Productivity, three tools are going to a phase-out in the selected time frame:
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2746f8657a441014bc86e6732760b21b_LowRes.png)
In the Rolled-up Layout, upon clicking on any view bucket, a side pane opens, highlighting the changes:
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274ceb347a441014a62098ca6344b701_LowRes.png)
On hovering over, it will also explain what change has been happening:
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275063257a441014bc2ae607c094b626_LowRes.png)
Users can also navigate from the side pane to a more specific "zoomed in" report by selecting New Landscape report from the Show in drop-down menu.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27468ab97a441014bbfe89676afbfd20_LowRes.png)
The zoomed-in report opens in a new browser window with the following features:
  1. The name is changed to highlight the “zoom in”.
  2. Filters are changed so only the selected cell or cluster is shown
  3. Any other settings are copied over (e.g., differential view)
  4. Items in the cell or cluster are sorted by view legend


![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275228757a44101491e8a9ad52f50c91_LowRes.png)
